# REL09-BP01: Identify all data that needs to be backed up

## Description

Create data inventory để identify backup requirements.

## Implementation Guidance

- Catalog all data stores
- Classify data by criticality
- Identify data dependencies
- Document data ownership
- Include configuration data

## Risk Level

High - Unidentified data won't be backed up.

## Related Best Practices

- [REL09-BP02](REL09-BP02-Establish-RPO.md)
- [SEC07-BP01](../../02-SEC/SEC07-Data-Data-Classification/SEC07-BP01-Identify-Data.md)
